[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Natural Language Processing client library for Python

[![API Version](https://img.shields.io/badge/api-v1.3.0-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.NaturalLanguageProcessing)](https://pypi.org/project/fds.sdk.NaturalLanguageProcessing/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

APIs that leverage Natural Language Processing to help extract meaningful data from unstructured text

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.0
- SDK version: 0.23.6
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.NaturalLanguageProcessing==0.23.6
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.NaturalLanguageProcessing==0.23.6
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.NaturalLanguageProcessing
from fds.sdk.NaturalLanguageProcessing.api import ai_text_summarization_api
from fds.sdk.NaturalLanguageProcessing.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.NaturalLanguageProcessing.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.NaturalLanguageProcessing.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.NaturalLanguageProcessing.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ai_text_summarization_api.AITextSummarizationApi(api_client)
    summarization_request = SummarizationRequest(
        text="Advanced Energy Transforms Indoor Farming With Intelligent New Lighting Power and Control System Friday, December 11, 2020 01:00:00 PM (GMT)Innovative technology breaks down barriers to indoor, vertical and greenhouse farming by reducing power consumption, cutting costs and increasing crop yield Advanced Energy (Nasdaq: AEIS) – a global leader in highly engineered, precision power conversion, measurement, and control solutions – today unveiled its newest lighting and power control system for indoor, vertical and greenhouse farming. This press release features multimedia. Advanced Energy's new Artesyn iTS provides the industry's first solution for switching or sharing a single power source between two different rooms. This reduces installation costs by cutting the number of iHP power supplies needed in half and it substantially reduces ongoing utility costs. (Photo: Business Wire)AE's new lighting and power system transforms the use of LED technology in horticultural lighting systems, which plays a fundamental role in cutting-edge farming practices that can address production challenges in food, pharmaceutical ingredients, plants and flowers. Utilizing AE's system, customers reduce their power conversion costs by as much as 50 percent, significantly lower installation and operating costs, and increase the quality of crop yield. "Our groundbreaking lighting, power and control system delivers significant improvements over conventional lighting solutions and opens up new opportunities for the industry," said Joe Voyles, vice president, industrial marketing, at Advanced Energy. "We are transforming our customers' operations by both reducing the amount of needed equipment and improving the efficiency of the lighting systems, thereby reducing cost and energy spend. Not only do these innovative new products increase the efficiency and quality of fruit and vegetable production, but they also open the door to establishing indoor farming facilities in harsh environments anywhere in the world." The new system consists of the patented Artesyn iTS (intelligent Transfer Switch) and iHPS configurable power supply. Alongside Artesyn's compact new 12 kW 300 VDC module, AE delivers a cost-effective platform for the most advanced indoor farming applications. The system is estimated to produce a 38 percent savings to lighting power and control installation cost, while eliminating substantial amounts of wasted energy. The new iHPS is a "short" version of AE's market-leading iHP power supply. The shorter design allows for more space within the lighting and power cabinet for other crucial components, reduces the weight and cost, and increases the life of the system. The new iTS provides the industry's first solution for switching or sharing a single power source between two different rooms. This reduces installation costs by cutting the number of iHP power supplies needed in half and it substantially reduces ongoing utility costs.",
    ) # SummarizationRequest |  (optional)

    try:
        # Endpoint to generate a headline from text
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.summarization_headline(summarization_request=summarization_request)

        pprint(api_response)
    except fds.sdk.NaturalLanguageProcessing.ApiException as e:
        print("Exception when calling AITextSummarizationApi->summarization_headline: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Endpoint to generate a headline from text
    #     api_response, http_status_code, response_headers = api_instance.summarization_headline_with_http_info(summarization_request=summarization_request)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.NaturalLanguageProcessing.ApiException as e:
    #     print("Exception when calling AITextSummarizationApi->summarization_headline: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Endpoint to generate a headline from text
    #     async_result = api_instance.summarization_headline_async(summarization_request=summarization_request)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.NaturalLanguageProcessing.ApiException as e:
    #     print("Exception when calling AITextSummarizationApi->summarization_headline: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Endpoint to generate a headline from text
    #     async_result = api_instance.summarization_headline_with_http_info_async(summarization_request=summarization_request)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.NaturalLanguageProcessing.ApiException as e:
    #     print("Exception when calling AITextSummarizationApi->summarization_headline: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.NaturalLanguageProcessing

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.NaturalLanguageProcessing.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.NaturalLanguageProcessing

configuration = fds.sdk.NaturalLanguageProcessing.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.NaturalLanguageProcessing

configuration = fds.sdk.NaturalLanguageProcessing.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.NaturalLanguageProcessing

configuration = fds.sdk.NaturalLanguageProcessing.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/cognitive/nlp/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AITextSummarizationApi* | [**summarization_headline**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AITextSummarizationApi.md#summarization_headline) | **POST** /summarization/headline | Endpoint to generate a headline from text
*AITextSummarizationApi* | [**summarization_headline_and_summary**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AITextSummarizationApi.md#summarization_headline_and_summary) | **POST** /summarization/headline-and-summary | Endpoint to summarize and generate a headline from text
*AITextSummarizationApi* | [**summarization_result**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AITextSummarizationApi.md#summarization_result) | **GET** /summarization/result/{resultId} | Endpoint to obtain result of a particular summarization job
*AITextSummarizationApi* | [**summarization_summary**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AITextSummarizationApi.md#summarization_summary) | **POST** /summarization/summary | Endpoint to summarize text
*AIThemesApi* | [**themes_extract_themes**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AIThemesApi.md#themes_extract_themes) | **POST** /themes | Endpoint to begin theme extraction job
*AIThemesApi* | [**themes_get_status**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AIThemesApi.md#themes_get_status) | **GET** /themes/{id}/status | Endpoint to get the completion status of a themes job
*AIThemesApi* | [**themes_get_themes**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/AIThemesApi.md#themes_get_themes) | **GET** /themes/{id} | Endpoint to get a theme (and sentiments if requested) job result
*NamedEntityRecognitionApi* | [**ner_entities**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NamedEntityRecognitionApi.md#ner_entities) | **POST** /ner/entities | Endpoint to detect entities from text
*QuestionAnswerApi* | [**qna_get_answers**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QuestionAnswerApi.md#qna_get_answers) | **GET** /qna/answers/{id} | Endpoint to get the answer(s)
*QuestionAnswerApi* | [**qna_get_status**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QuestionAnswerApi.md#qna_get_status) | **GET** /qna/answers/{id}/status | Endpoint to get the completion status for a Q&amp;A request
*QuestionAnswerApi* | [**qna_post_question**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QuestionAnswerApi.md#qna_post_question) | **POST** /qna/answers | Endpoint to submit a question for answer(s)


## Documentation For Models

 - [Error](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/Error.md)
 - [ErrorSource](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ErrorSource.md)
 - [HTTPError](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/HTTPError.md)
 - [HTTPErrorRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/HTTPErrorRoot.md)
 - [NEREntity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NEREntity.md)
 - [NEREntityList](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NEREntityList.md)
 - [NERInputDataSchema](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NERInputDataSchema.md)
 - [NERInputSchema](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NERInputSchema.md)
 - [NEROrganization](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NEROrganization.md)
 - [NERResponseSchema](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/NERResponseSchema.md)
 - [QnAAnswer](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QnAAnswer.md)
 - [QnAAnswerParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QnAAnswerParameters.md)
 - [QnAAnswerParametersRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QnAAnswerParametersRoot.md)
 - [QnAAnswerRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/QnAAnswerRoot.md)
 - [SummarizationHTTPError](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/SummarizationHTTPError.md)
 - [SummarizationRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/SummarizationRequest.md)
 - [SummarizationResult](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/SummarizationResult.md)
 - [SummarizationResultID](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/SummarizationResultID.md)
 - [Task](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/Task.md)
 - [TaskRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/TaskRoot.md)
 - [ThemeSentiment](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ThemeSentiment.md)
 - [ThemeSentimentsRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ThemeSentimentsRoot.md)
 - [ThemesParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ThemesParameters.md)
 - [ThemesParametersRoot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ThemesParametersRoot.md)
 - [ValidationError](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ValidationError.md)
 - [ValidationErrorDetail](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ValidationErrorDetail.md)
 - [ValidationErrorDetailLocation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/NaturalLanguageProcessing/v1/docs/ValidationErrorDetailLocation.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.NaturalLanguageProcessing.apis and fds.sdk.NaturalLanguageProcessing.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.NaturalLanguageProcessing.api.default_api import DefaultApi`
- `from fds.sdk.NaturalLanguageProcessing.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.NaturalLanguageProcessing
from fds.sdk.NaturalLanguageProcessing.apis import *
from fds.sdk.NaturalLanguageProcessing.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

